==> node-espree_7.3.1~dfsg1.orig.tar.xz: espree-7.3.1/tests/fixtures/ecma-version/9/regexp-named-group/valid-backreference-1.result.js <==
const conditionalRegex = require("../../../../lib/conditional-regex-value");

module.exports = {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 1,
            "column": 26
        }
    },
    "range": [
        0,
        26
    ],
    "body": [
        {
            "type": "ExpressionStatement",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 26
                }
            },
            "range": [
                0,
                26
            ],
            "expression": conditionalRegex({
                "type": "Literal",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 0
                    },
                    "end": {
                        "line": 1,
                        "column": 26
                    }
                },
                "range": [
                    0,
                    26
                ],
                "value": null,
                "raw": "/(?<\\u0041\\u0042>a)\\k<AB>/",
                "regex": {
                    "pattern": "(?<\\u0041\\u0042>a)\\k<AB>",
                    "flags": ""
                }
            })
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "RegularExpression",
            "value": "/(?<\\u0041\\u0042>a)\\k<AB>/",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 26
                }
            },
            "range": [
                0,
                26
            ],
            "regex": {
                "flags": "",
                "pattern": "(?<\\u0041\\u0042>a)\\k<AB>"
            }
        }
    ]
};

==> node-espree_9.4.1~dfsg.orig.tar.xz: espree-9.4.1/tests/fixtures/ecma-version/9/regexp-named-group/valid-backreference-1.result.js <==
import conditionalRegex from "../../../../lib/conditional-regex-value.js";

export default {
    "type": "Program",
    "loc": {
        "start": {
            "line": 1,
            "column": 0
        },
        "end": {
            "line": 1,
            "column": 26
        }
    },
    "range": [
        0,
        26
    ],
    "body": [
        {
            "type": "ExpressionStatement",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 26
                }
            },
            "range": [
                0,
                26
            ],
            "expression": conditionalRegex({
                "type": "Literal",
                "loc": {
                    "start": {
                        "line": 1,
                        "column": 0
                    },
                    "end": {
                        "line": 1,
                        "column": 26
                    }
                },
                "range": [
                    0,
                    26
                ],
                "value": null,
                "raw": "/(?<\\u0041\\u0042>a)\\k<AB>/",
                "regex": {
                    "pattern": "(?<\\u0041\\u0042>a)\\k<AB>",
                    "flags": ""
                }
            })
        }
    ],
    "sourceType": "script",
    "tokens": [
        {
            "type": "RegularExpression",
            "value": "/(?<\\u0041\\u0042>a)\\k<AB>/",
            "loc": {
                "start": {
                    "line": 1,
                    "column": 0
                },
                "end": {
                    "line": 1,
                    "column": 26
                }
            },
            "range": [
                0,
                26
            ],
            "regex": {
                "flags": "",
                "pattern": "(?<\\u0041\\u0042>a)\\k<AB>"
            }
        }
    ]
};
